//
//  MiniAppLauncher.swift
//  MiniAppConnector
//
//  Created by Teko on 23/09/2021.
//

import UIKit
import HestiaIOS
import Hestia
import UIKit
import MiniApp

enum Scenario: String {
    case openAppWithoutLogin
    case openAppWithLogin
    case payment
}

public class MiniAppLauncher: IOSAppLauncherProtocol {
    
    required public init() {
        // Custom your launcher
    }
    
    public func create(launcherData: AppLauncherData, completion: @escaping (UIViewController?) -> ()) {
        guard let scenarioString = launcherData.extraConfig["scenario"] as? String,
              let scenario = Scenario(rawValue: scenarioString) else { return }
        
        switch scenario {
        case .openAppWithoutLogin:
            // Create a mini app ViewController which do not require token
            MiniAppSDK.createViewController { vc in
                completion(vc)
            }
            
        case .openAppWithLogin:
            guard let idToken = launcherData.authResult?.idToken else { return }
            
            // Create a mini app ViewController which requires an idToken
            MiniAppSDK.createLoginRequiredViewController(idToken: idToken) { vc in
                completion(vc)
            }
            
        case .payment:
            // Create a mini app WiewController which can process payment
            MiniAppSDK.createPaymentProcessableViewController { vc in
                completion(vc)
            }
        }
    }
    
}
