//
//  UIViewController+.swift
//  SanboxApp
//
//  Created by Teko on 23/09/2021.
//

import UIKit

extension UIViewController {
    
    static func instantiateFromNib() -> Self {
        func instantiateFromNib<T: UIViewController>(_ viewType: T.Type) -> T {
            if UIDevice.current.userInterfaceIdiom == .pad {
                let nibName = String.init(format: "%@_iPad", String(describing: T.self))
                if Bundle(for: T.self).path(forResource: nibName, ofType: "nib") != nil {
                    return T.init(nibName: nibName, bundle: Bundle(for: T.self))
                }
            }
            return T.init(nibName: String(describing: T.self), bundle: Bundle(for: T.self))
        }
        return instantiateFromNib(self)
    }
    
    func showAlert(message: String) {
        let alert = UIAlertController(title: Strings.alert, message: message, preferredStyle: .alert)
        alert.addAction(UIAlertAction(title: Strings.ok, style: .cancel, handler: nil))
        DispatchQueue.main.async {
            self.present(alert, animated: true, completion: nil)
        }
    }
    
}
