//
//  MainProtocols.swift
//  SandboxApp
//
//  Created by Teko on 23/09/2021.
//

import Foundation
import JanusUI
import Hestia

protocol MainViewProtocol: AnyObject {
    var presenter: MainPresenterProtocol? { get set }
    
    func fillAppCode(appCode: String)
    func showAlert(message: String)
    func updateUI()
    func reloadAuthState()
}

protocol MainPresenterProtocol: AnyObject {
    var isLoggedIn: Bool { get }
    
    var scenarios: [Scenario] { get }
    var appTypes: [MiniAppType] { get }
//    var requiredAppCode: Bool { get }
    var selectedScenario: Scenario { get }
    var selectedAppType: MiniAppType { get }
    var appCode: String { get }
    
    func selectScenario(at index: Int)
    func selectAppType(at index: Int)
    func appCodeChanged(appCode: String)
    func didTapOpenApp()
    func didTapLogin()
    func didTapDefault()
}

protocol MainRouterProtocol: AnyObject {
    func openLoginUI(delegate: LoginUIDelegate)
    func openMiniApp(appType: MiniAppType, scenario: Scenario, appCode: String, delegate: HestiaCallback)
}
