//
//  TerraAppManager.swift
//  SandboxApp
//
//  Created by Teko on 23/09/2021.
//

import Foundation
import Terra
import TekoTracker
import ApolloTheme
import MinervaUI
import JanusUI
import Janus
import Hestia
import TekIrisService
import LoyaltyCore

var terraHestia = TerraHestia.getInstance(by: TerraAppManager.shared.getTerraApp())
var terraAuth = TerraAuth.getInstance(by: TerraAppManager.shared.getTerraApp())
var terraAuthUI = TerraAuthUI.getInstance(by: TerraAppManager.shared.getTerraApp())

class TerraAppManager {
        
    static let shared = TerraAppManager()
    static let appName = "SandboxApp"

    private init() {}
    
    private var terraApp: ITerraApp!
    
    func getTerraApp() -> ITerraApp {
        guard let app = terraApp else {
            fatalError("TerraApp has not been configured")
        }
        return app
    }
    
    func loadTerraApp(completion: @escaping () -> ()) {
        TerraApp.configure(appName: TerraAppManager.appName) { [weak self] success, terraApp in
            self?.terraApp = terraApp
            self?.configureTerraModules(app: terraApp)
            completion()
        }
    }
    
    func configureTerraModules(app: ITerraApp) {
        configureTracker(app: app)
        configureAuth(app: app)
        configureTheme(app: app)
        configureLoyalty(app: app)
        configurePayment(app: app)
        configureHestia(app: app)
    }
    
    func configureTracker(app: ITerraApp) {
        TerraTracker.configureWith(app: app)
    }
    
    func configureAuth(app: ITerraApp) {
        TerraAuthUI.configureWith(app: app)
        TerraAuth.getInstance(by: app)?.registerGoogle()
    }
    
    func configurePayment(app: ITerraApp) {
        TerraIris.configureWith(app: app)
        TerraPaymentUI.configureWith(app: app)
    }
    
    func configureTheme(app: ITerraApp) {
        TerraTheme.configureWith(app: app)
    }
    
    func configureHestia(app: ITerraApp) {
        TerraHestia.configureWith(app: app)
    }
    
    func configureLoyalty(app: ITerraApp) {
        TerraLoyalty.configureWith(app: app)
    }
}
