import React from 'react';
import { AppRegistry, StyleSheet, View, Text, Image, Button, SafeAreaView, ScrollView } from 'react-native';
import '@terra-js/react-native-bridge';
import TerraKit from '@terra-js/terra-kit';
import PaymentKit, { PaymentRequestBuilder } from '@terra-js/payment-kit';
import { MainMethodType } from '@terra-js/payment-kit/dist/constansts';

const App = (props) => {
  const onFinish = () => {
    TerraKit.finish();
  };

  const onClickPayment = () => {

    const amount = 150000;

    const paymentRequestBuilder = new PaymentRequestBuilder();

    paymentRequestBuilder
        .setOrder({
            orderCode: "abcd12345",
            orderAmount: amount,
        })
        .setPaymentMethods({
            mainMethod: {
                method: MainMethodType.All,
                amount,
            },
            totalAmount: amount,
        })
        .setOptions({
            shouldShowPaymentResultScreen: true,
        });

    PaymentKit.payForOrder(paymentRequestBuilder.build()).then((result) => {
        switch (result.resultCode) {
            case 'succeeded':
                alert("Thanh toán thành công");
                break;
            case 'failed':
                alert("Thanh toán thất bại");
                break;
        }
    });

  };

  return (
    <SafeAreaView style={{ flex: 1 }}>
      <View style={styles.container}>
        <View style={styles.idTokenContainer}>

          <Text style={styles.idTokenLabel}>Id Token:</Text>
          <ScrollView>
            <Text>{props.terraIdToken}</Text>
          </ScrollView>
        </View>
        <Button title="Payment" onPress={onClickPayment} style={{ marginTop: 16 }} />
        <Button title="Finish app" onPress={onFinish} style={{ marginTop: 16 }} />
      </View>
    </SafeAreaView>
  );
};

const styles = StyleSheet.create({
  container: {
    flex: 1,
    backgroundColor: 'white',
    padding: 16,
  },
  image: {
    width: 400,
    height: 100,
  },
  idTokenContainer: {
    flex: 1,
    marginTop: 12,
  },
  idTokenLabel: {
    fontWeight: 'bold',
    fontSize: 15,
    color: 'black',
  },
});

export default App;

// Module name
AppRegistry.registerComponent('RNMain', () => App);
